==> haskell-descriptive-0.9.5-57-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-descriptive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: descriptive
version: 0.9.5
id: descriptive-0.9.5-HY6KT5p5Ikh8DGq6SQdhBZ
key: descriptive-0.9.5-HY6KT5p5Ikh8DGq6SQdhBZ
license: BSD-3-Clause
copyright: 2015 Chris Done
maintainer: chrisdone@gmail.com
author: Chris Done
stability: Experimental
homepage: https://github.com/chrisdone/descriptive
synopsis: Self-describing consumers/parsers; forms, cmd-line args, JSON, etc.
description:
    Self-describing consumers/parsers. See the README.md for more information. It is currently EXPERIMENTAL.
category: Parsing
abi: 181066b64e04bf2c99c2435e324adefc
exposed: True
exposed-modules:
    Descriptive Descriptive.Char Descriptive.Form Descriptive.Formlet
    Descriptive.JSON Descriptive.Options
hidden-modules: Descriptive.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/descriptive-0.9.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/descriptive-0.9.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/descriptive-0.9.5
hs-libraries: HSdescriptive-0.9.5-HY6KT5p5Ikh8DGq6SQdhBZ
depends:
    aeson-1.4.4.0-KwovUsQGNt8PPlzoq6sTW base-4.12.0.0
    bifunctors-5.5.4-9Tb0bkUz5VW2Ucg8P8K6vJ containers-0.6.0.1
    mtl-2.2.2 scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b text-1.2.3.1
    transformers-0.5.6.2 vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-descriptive/html/descriptive.haddock
haddock-html: /usr/share/doc/haskell-descriptive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-descriptive-0.9.5-62-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-descriptive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: descriptive
version: 0.9.5
id: descriptive-0.9.5-9Tkg7Mf9QZeDfLZ2zg7HZd
key: descriptive-0.9.5-9Tkg7Mf9QZeDfLZ2zg7HZd
license: BSD-3-Clause
copyright: 2015 Chris Done
maintainer: chrisdone@gmail.com
author: Chris Done
stability: Experimental
homepage: https://github.com/chrisdone/descriptive
synopsis: Self-describing consumers/parsers; forms, cmd-line args, JSON, etc.
description:
    Self-describing consumers/parsers. See the README.md for more information. It is currently EXPERIMENTAL.
category: Parsing
abi: 1a97d9931aaef5c0a04948beacd05ea3
exposed: True
exposed-modules:
    Descriptive Descriptive.Char Descriptive.Form Descriptive.Formlet
    Descriptive.JSON Descriptive.Options
hidden-modules: Descriptive.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/descriptive-0.9.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/descriptive-0.9.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/descriptive-0.9.5
hs-libraries: HSdescriptive-0.9.5-9Tkg7Mf9QZeDfLZ2zg7HZd
depends:
    aeson-1.4.4.0-B759jesA16BBzbLoqI31GW base-4.12.0.0
    bifunctors-5.5.5-AT2O4t2mUeVLY6LKXIjARE containers-0.6.0.1
    mtl-2.2.2 scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b text-1.2.3.1
    transformers-0.5.6.2 vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-descriptive/html/descriptive.haddock
haddock-html: /usr/share/doc/haskell-descriptive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
